diff code_part1/OSTC_code_asm_part1/pled_outputs.asm @ 163:144822282fa3

Fusion declaration of shared C/ASM variables. + remove unused variables. + sort all in variables in BANK3, and out variables in BANK2.
author JeanDo
date Fri, 21 Jan 2011 01:44:37 +0100
parents 54cc1346ac15
children 999abb01c78f
line wrap: on
line diff
--- a/code_part1/OSTC_code_asm_part1/pled_outputs.asm	Fri Jan 21 01:48:40 2011 +0100
+++ b/code_part1/OSTC_code_asm_part1/pled_outputs.asm	Fri Jan 21 01:44:37 2011 +0100
@@ -980,9 +980,9 @@
     movff   WREG,letter+5		; collision with sat graphs
 	bcf		leftbind
 	call	word_processor
 ;	rcall	PLED_active_gas_divemode_better_gas	; show *, if required
 ;	return
-PLED_active_gas_divemode_better_gas:
+PLED_active_better_gas:
 	WIN_TOP		.192
 	WIN_LEFT	.43
 	WIN_FONT 	FT_SMALL
@@ -1007,7 +1007,7 @@
     movff   WREG,letter+5		; collision with sat graphs
 	bcf		leftbind
 	call	word_processor
-	rcall	PLED_active_gas_divemode_better_gas	; show *, if required
+	rcall	PLED_active_better_gas	; show *, if required
 	return
 
 PLED_display_decotype_surface:
@@ -980,9 +980,9 @@
 	bcf		leftbind
 	call	word_processor
-;	rcall	PLED_active_gas_divemode_better_gas	; show *, if required
+;	rcall	PLED_active_better_gas	; show *, if required
 ;	return